@@ -84,6 +84,7 @@ class APIClient:
         self.ICP_40 = False # Use it for any 4.0 specific functionalities
         self.ICP_45 = False # Use it for any 4.5 specific functionalities
         self.CLOUD_BETA_FLOW = False
+        self._iam_id = None
 
         self.PLATFORM_URLS_MAP = {
             'https://wml-dev.ml.test.cloud.ibm.com': 'https://api.dataplatform.dev.cloud.ibm.com',
@@ -438,6 +439,8 @@ class APIClient:
 
         if self.default_project_id and self.project_type == 'local_git_storage':
             params.update({'userfs': 'true'})
+            if self._iam_id:
+                params.update({'iam_id': str(self._iam_id)})
 
         if (not self.default_project_id or self.project_type != 'local_git_storage') and 'userfs' in params:
             del params['userfs']
