@@ -107,6 +107,9 @@ class Connections(WMLResource):
         else:
             header_param = self._client._get_headers()
 
+        if self._client._iam_id:
+            header_param['IBM-WDP-Impersonate'] = str({'iam_id': str(self._client._iam_id)})
+
         if connection_id:
             response = requests.get(
                 self._client.service_instance._href_definitions.get_connection_by_id_href(connection_id),
