@@ -69,7 +69,7 @@ class ExperimentIterableDataset(IterableDataset):
         connection: "DataConnection",
         experiment_metadata: dict = None,
         enable_sampling: bool = True,
-        sample_size_limit: int = 1073741824 if "32" in os.environ.get("MEM", "32") else 104857600,  # 1GB in Bytes,
+        sample_size_limit: int = 1073741824,  # 1GB in Bytes is verified later by _set_sample_size_limit,
         sampling_type: str = SamplingTypes.FIRST_N_RECORDS,
         binary_data: bool = False,
         number_of_batch_rows: int = None,
@@ -77,6 +77,7 @@ class ExperimentIterableDataset(IterableDataset):
         **kwargs,
     ):
         super().__init__()
+        self._set_sample_size_limit_()
         self.experiment_metadata = experiment_metadata
         self.enable_sampling = enable_sampling
         self._wml_client = getattr(connection, "_wml_client", None)
@@ -113,7 +114,6 @@ class ExperimentIterableDataset(IterableDataset):
         # --- end note
 
         # if number_of_batch_rows is provided, batch_size does not matter anymore
-
         if self.authorized:
             # first used headers from experiment metadata if they were set.
             headers_ = None
@@ -121,7 +121,6 @@ class ExperimentIterableDataset(IterableDataset):
                 headers_ = self.experiment_metadata.get("headers")
             elif self._wml_client is not None:
                 headers_ = self._wml_client._get_headers()
-
             self.connection = FlightConnection(
                 headers=headers_,
                 sampling_type=self.sampling_type,
@@ -145,6 +144,7 @@ class ExperimentIterableDataset(IterableDataset):
             )
 
         else:
+
             if (
                 dict_connection.get("type") == "fs"
                 and "location" in dict_connection
@@ -187,6 +187,19 @@ class ExperimentIterableDataset(IterableDataset):
         else:
             return False
 
+    def _set_sample_size_limit_(self):
+        """Set Sample Size Limit based on T-Shirt size if code is run on training pod
+        For memory < 32 (T-Shirts: XS,S, M) default is 100MB,
+        For memory >= 32 or runs outside pod default is 1GB
+        """
+        import re
+
+        size_mem = int(re.findall(r'[0-9]+', os.environ.get('MEM', '32'))[0])
+        if size_mem >= 32:
+            self.sample_size_limit = 1073741824     # 1GB in bytes
+        else:
+            self.sample_size_limit = 104857600      # 100MB in bytes
+
     def write(
         self, data: Optional[pd.DataFrame] = None, file_path: Optional[str] = None
     ) -> None:
