@@ -98,7 +98,8 @@ class WebService(BaseDeployment):
                metadata: Optional[Dict] = None,
                training_data: Optional[Union['DataFrame', 'ndarray']] = None,
                training_target: Optional[Union['DataFrame', 'ndarray']] = None,
-               experiment_run_id: Optional[str] = None) -> None:
+               experiment_run_id: Optional[str] = None,
+               hardware_spec: Optional[dict] = None) -> None:
         """
         Create deployment from a model.
 
@@ -125,6 +126,9 @@ class WebService(BaseDeployment):
         experiment_run_id: str, optional
             ID of a training/experiment (only applicable for AutoAI deployments)
 
+        hardware_spec: dict, optional
+            Hardware specification for deployment
+
         Example
         -------
         >>> from ibm_watson_machine_learning.deployment import WebService
@@ -155,7 +159,8 @@ class WebService(BaseDeployment):
                               training_data=training_data,
                               training_target=training_target,
                               experiment_run_id=experiment_run_id,
-                              deployment_type='online')
+                              deployment_type='online',
+                              hardware_spec=hardware_spec)
 
     @BaseDeployment._project_to_space_to_project
     def get_params(self) -> Dict:
@@ -268,7 +273,8 @@ class WebService(BaseDeployment):
                 deployment_name: str,
                 meta_props: Dict,
                 serving_name=None,
-                result_client=None) -> Dict:
+                result_client=None,
+                hardware_spec=None) -> Dict:
         """
         Deploy model into WML.
 
@@ -289,7 +295,6 @@ class WebService(BaseDeployment):
         result_client: Tuple['DataConnection', 'resource'] required
             Tuple with Result DataConnection object and initialized COS client.
         """
-        deployment_details = {}
         asset_uid = self._publish_model(pipeline_model=pipeline_model,
                                         meta_props=meta_props)
 
@@ -299,12 +304,12 @@ class WebService(BaseDeployment):
 
         deployment_props = {
             conf_names.NAME: deployment_name,
-            conf_names.ONLINE: {},
-            "hardware_spec": {
-                "name": "M",
-            }
+            conf_names.ONLINE: {}
         }
 
+        if hardware_spec:
+            deployment_props[conf_names.HARDWARE_SPEC] = hardware_spec
+
         if serving_name:
             deployment_props[conf_names.ONLINE]["parameters"] = {conf_names.SERVING_NAME: serving_name}
 
