@@ -184,7 +184,7 @@ class AutoAI(BaseExperiment):
                   word2vec_feature_number: int = None,
                   daub_give_priority_to_runtime: float = None,
                   fairness_info: dict = None,
-                  # sampling_type: 'SamplingTypes' = None, #TODO: Uncomment to add sampling_type support
+                  sampling_type: 'SamplingTypes' = None,
                   n_parallel_data_connections: int = None,
                   categorical_imputation_strategy: ImputationStrategy = None,
                   numerical_imputation_strategy: ImputationStrategy = None,
@@ -367,6 +367,11 @@ class AutoAI(BaseExperiment):
         numerical_columns: list, optional
             List of columns names that must be treated as numerical.
 
+        sampling_type: str, optional
+            Type of sampling data for training. One of SamplingTypes enum values.
+            Default is SamplingTypes.FIRST_N_RECORDS.
+            Supported only for IBM Cloud Pak® for Data 4.0.1 and above.
+
         test_data_csv_separator: Union[List[str], str], optional
             The separator, or list of separators to try for separating
             columns in a CSV user-defined holdout/test file.  Not used if the file_name is not a CSV file.
@@ -379,6 +384,7 @@ class AutoAI(BaseExperiment):
         test_data_encoding: str, optional
             Encoding type for CSV user-defined holdout/test file.
 
+
         Returns
         -------
         RemoteAutoPipelines or LocalAutoPipelines, depends on how you initialize the AutoAI object.
@@ -434,11 +440,19 @@ class AutoAI(BaseExperiment):
         elif 'global_stage_include_batched_ensemble_estimators' in kwargs:
             include_batched_ensemble_estimators = kwargs.pop('global_stage_include_batched_ensemble_estimators')  # TODO to be removed
 
-        # TODO: Pass the sampling_type doc description, when adding support for that
-        # sampling_type: str, optional
-        #     Type of sampling data for training. One of SamplingTypes enum values.
-        #     Default is SamplingTypes.FIRST_N_RECORDS.
-        #     Supported only for IBM Cloud Pak® for Data 4.0.1 and above.
+        # TS exogenous, to be removed
+        supporting_features = None
+        pipeline_types = None
+        supporting_features_at_forecasting = None
+
+        if 'supporting_features' in kwargs:
+            supporting_features = kwargs.pop('supporting_features')
+
+        if 'pipeline_types' in kwargs:
+            pipeline_types = kwargs.pop('pipeline_types')
+
+        if 'supporting_features_at_forecasting' in kwargs:
+            supporting_features_at_forecasting = kwargs.pop('supporting_features_at_forecasting')
 
         # Deprecation of excel_sheet as number:
         if isinstance(excel_sheet, int):
@@ -612,7 +626,7 @@ class AutoAI(BaseExperiment):
                 autoai_pod_version=kwargs.get('autoai_pod_version', None),
                 obm_pod_version=kwargs.get('obm_pod_version', None),
                 fairness_info=fairness_info,
-                # sampling_type=sampling_type, #TODO: Uncomment to add sampling_type support
+                sampling_type=sampling_type,
                 n_parallel_data_connections=n_parallel_data_connections,
                 categorical_imputation_strategy=categorical_imputation_strategy,
                 numerical_imputation_strategy=numerical_imputation_strategy,
@@ -621,6 +635,9 @@ class AutoAI(BaseExperiment):
                 retrain_on_holdout=retrain_on_holdout,
                 numerical_columns=numerical_columns,
                 categorical_columns=categorical_columns,
+                supporting_features=supporting_features,
+                pipeline_types=pipeline_types,
+                supporting_features_at_forecasting=supporting_features_at_forecasting,
                 test_data_csv_separator=test_data_csv_separator,
                 test_data_excel_sheet=test_data_excel_sheet,
                 test_data_encoding=test_data_encoding,
