@@ -220,6 +220,22 @@ class WMLEngine(BaseEngine):
                 self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                     'pipelines'][0]['nodes'][0]['parameters']['optimization'][
                     'gap_len'] = self._auto_pipelines_parameters['backtest_gap_length']
+            if self._auto_pipelines_parameters['supporting_features']:
+                self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                    'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                    'feature_columns'] = self._auto_pipelines_parameters['supporting_features']
+            if self._auto_pipelines_parameters['pipeline_types']:
+                self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                    'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                    'pipeline_type'] = 'customized'
+                self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                    'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                    'customized_pipelines'] = [pipeline.value for pipeline in
+                                               self._auto_pipelines_parameters['pipeline_types']]
+            if self._auto_pipelines_parameters['supporting_features_at_forecasting'] != None:
+                self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                    'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                    'future_exogenous_available'] = self._auto_pipelines_parameters['supporting_features_at_forecasting']
             self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                 'pipelines'][0]['nodes'][0]['parameters'][
                 'compute_pipeline_notebooks_flag'] = self._auto_pipelines_parameters.get('notebooks', False)
