@@ -26,7 +26,8 @@ from ibm_watson_machine_learning.helpers.connections import (
     DataConnection, S3Location, FSLocation, AssetLocation, WSDAssetLocation, ContainerLocation, DatabaseLocation)
 from ibm_watson_machine_learning.preprocessing import DataJoinPipeline
 from ibm_watson_machine_learning.utils.autoai.enums import (
-    RunStateTypes, PipelineTypes, TShirtSize, ClassificationAlgorithms, RegressionAlgorithms, DataConnectionTypes)
+    RunStateTypes, PipelineTypes, TShirtSize, ClassificationAlgorithms, RegressionAlgorithms, DataConnectionTypes,
+    ForecastingPipelineTypes)
 from ibm_watson_machine_learning.utils.autoai.errors import (
     FitNotCompleted, MissingDataPreprocessingStep, WrongDataJoinGraphNodeName, DataSourceSizeNotSupported,
     TrainingDataSourceIsNotFile, NoneDataConnection, PipelineNotLoaded, OBMForNFSIsNotSupported,
@@ -156,13 +157,16 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                  test_data_csv_separator: Union[List[str], str] = ',',
                  test_data_excel_sheet: Union[str, int] = None,
                  test_data_encoding: str = 'utf-8',
-                 # sampling_type=None,  #TODO: Uncomment to add sampling_type support
+                 sampling_type=None,
                  categorical_imputation_strategy=None,
                  numerical_imputation_strategy=None,
                  numerical_imputation_value=None,
                  imputation_threshold=None,
                  fairness_info: dict = None,
                  retrain_on_holdout: bool = True,
+                 supporting_features: List[str] = None,
+                 pipeline_types: List['ForecastingPipelineTypes'] = None,
+                 supporting_features_at_forecasting: bool = None,
                  **kwargs):
 
         if data_join_graph is not None:
@@ -206,7 +210,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             'word2vec_feature_number': word2vec_feature_number,
             'daub_give_priority_to_runtime': daub_give_priority_to_runtime,
             'text_columns_names': text_columns_names,
-            # 'sampling_type': sampling_type, #TODO: Uncomment to add sampling_type support
+            'sampling_type': sampling_type,
             'n_parallel_data_connections': n_parallel_data_connections,
             'test_data_csv_separator': test_data_csv_separator,
             'test_data_excel_sheet': test_data_excel_sheet,
@@ -215,7 +219,10 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             'numerical_imputation_strategy': numerical_imputation_strategy,
             'numerical_imputation_value': numerical_imputation_value,
             'imputation_threshold': imputation_threshold,
-            'retrain_on_holdout': retrain_on_holdout
+            'retrain_on_holdout': retrain_on_holdout,
+            'supporting_features': supporting_features,
+            'pipeline_types': pipeline_types,
+            'supporting_features_at_forecasting': supporting_features_at_forecasting
         }
 
         if fairness_info:
