@@ -197,7 +197,7 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
             csv_separator = optimizer_config['entity']['document']['pipelines'][0]['nodes'][kb_node_number][
                 'parameters'].get('input_file_separator', ',')
             excel_sheet = optimizer_config['entity']['document']['pipelines'][0]['nodes'][kb_node_number][
-                'parameters'].get('excel_sheet', 0)
+                'parameters'].get('excel_sheet', None)
             encoding = optimizer_config['entity']['document']['pipelines'][0]['nodes'][kb_node_number][
                 'parameters'].get('encoding', 'utf-8')
             drop_duplicates = optimizer_config['entity']['document']['pipelines'][0]['nodes'][kb_node_number][
