@@ -398,6 +398,56 @@ class BaseDataConnection(ABC):
             else:
                 return False  # if we are in WS, ignore this check even if there was some error
 
+    def _is_data_asset_normal(self) -> bool:
+        """Returns true if data asset is normal data asset - not connected data asset"""
+        try:
+            if self.type == 'data_asset':
+                if self.connection is not None and hasattr(self.connection, 'href'):
+                    items = self.connection.href.split('/')
+                else:
+                    items = self.location.href.split('/')
+                _id = items[-1].split('?')[0]
+
+                if self._wml_client is not None:
+                    attachment_details = self._get_attachemnt_details(_id)
+                    return bool('connection_id' not in attachment_details)
+
+                else:
+                    try:
+                        from project_lib import Project
+                        project = Project.access()
+
+                        # note: Check if asset is located directly in the project files
+                        #       If yes it is not a connected data.
+                        #       [Prevents unnecessary logging].
+                        return any(file['asset_id'] == _id for file in project.get_files())
+                        # --- end note
+
+                    except ModuleNotFoundError:
+                        raise NotImplementedError(f"This functionality can be run only on Watson Studio.")
+
+        except Exception as e:
+            if os.environ.get('USER_ACCESS_TOKEN') is None:
+                raise e
+            else:
+                return False  # if we are in WS, ignore this check even if there was some error
+
+    def _is_data_asset_nfs(self):
+        if self.type == 'data_asset':
+            if self.connection is not None and hasattr(self.connection, 'href'):
+                items = self.connection.href.split('/')
+            else:
+                items = self.location.href.split('/')
+            _id = items[-1].split('?')[0]
+
+            if self._wml_client is not None:
+                attachment_details = self._get_attachemnt_details(_id)
+
+                return ('connection_id' in attachment_details and attachment_details.get(
+                    'datasource_type') == self._wml_client.connections.get_datasource_type_uid_by_name('volumes'))
+        return False
+
+
     def _download_indices_from_cos(self, cos_client: 'resource', location_path) -> 'DataFrame':
         """Download indices for this connection. COS version"""
 
@@ -666,32 +716,49 @@ class BaseDataConnection(ABC):
         if not self._wml_client:
             raise CannotReadSavedRemoteDataBeforeFit()
 
+        buffer = None
+
         # Note: workaround with volumes API as connections API changes data format
-        connection_details = self._wml_client.connections.get_details(connection_id)
+        try:
+            connection_details = self._wml_client.connections.get_details(connection_id)
+        except ApiRequestFailure as conn_error:
+            if os.environ.get('TRAINING_NFS_PATH'):
+                # Note: Only viable on AutoAI runtime
+                base_path = os.environ.get('TRAINING_NFS_PATH') + "/0"
+                if connection_path.startswith('/'):
+                    data_path = f"{base_path}{connection_path}"
+                else:
+                    data_path = f"{base_path}/{connection_path}"
+                with open(data_path, 'rb') as f:
+                    buffer = io.BytesIO(f.read())
+            else:
+                raise conn_error
 
-        href = self._wml_client.volumes._client.service_instance._href_definitions.volume_upload_href(
-            connection_details['entity']['properties']['volume'])
-        full_href = f"{href[:-1]}{connection_path}"
-
-        csv_response = requests.get(full_href,
-                                    headers=self._wml_client._get_headers(),
-                                    stream=True)
-
-        # Note: if file is written in directory we need to create different href for download
-        if csv_response.status_code != 200:
-            path_parts = connection_path.split('/')
-            full_href = f"{href[:-1]}{'/'.join(path_parts[:-1])}%2F{path_parts[-1]}"
+        if buffer is None:
+            href = self._wml_client.volumes._client.service_instance._href_definitions.volume_upload_href(
+                connection_details['entity']['properties']['volume'])
+            full_href = f"{href[:-1]}{connection_path}"
 
             csv_response = requests.get(full_href,
                                         headers=self._wml_client._get_headers(),
                                         stream=True)
 
+            # Note: if file is written in directory we need to create different href for download
             if csv_response.status_code != 200:
-                raise ApiRequestFailure(u'Failure during {}.'.format("downloading data"), csv_response)
+                path_parts = connection_path.split('/')
+                full_href = f"{href[:-1]}{'/'.join(path_parts[:-1])}%2F{path_parts[-1]}"
+
+                csv_response = requests.get(full_href,
+                                            headers=self._wml_client._get_headers(),
+                                            stream=True)
+
+                if csv_response.status_code != 200:
+                    raise ApiRequestFailure(u'Failure during {}.'.format("downloading data"), csv_response)
+
+            downloaded_asset = csv_response.content
+            # note: read the csv/xlsx file from the memory directly into the pandas DataFrame
+            buffer = io.BytesIO(downloaded_asset)
 
-        downloaded_asset = csv_response.content
-        # note: read the csv/xlsx file from the memory directly into the pandas DataFrame
-        buffer = io.BytesIO(downloaded_asset)
         data = try_load_dataset(buffer=buffer,
                                 sheet_name=self.auto_pipeline_params.get('excel_sheet', 0),
                                 separator=self.auto_pipeline_params.get('csv_separator', ','),
