@@ -426,7 +426,7 @@ class DataConnection(BaseDataConnection):
                 learning_type="forecasting",
                 test_size=self.auto_pipeline_params.get('holdout_size'),
                 lookback_window=self.auto_pipeline_params.get('lookback_window'),
-                # feature_columns=None,
+                # supporting_features=None,
                 timestamp_column=self.auto_pipeline_params.get('timestamp_column_name'),
                 # n_jobs=None,
                 # tshirt_size=None,
@@ -688,7 +688,6 @@ class DataConnection(BaseDataConnection):
             headers = self._wml_client._get_headers()
 
             headers['impersonate'] = impersonate_header
-
         if self.type == DataConnectionTypes.S3:
             raise ConnectionError(
                 f"S3 DataConnection is deprecated! Please use data_asset_id instead.")
@@ -706,27 +705,30 @@ class DataConnection(BaseDataConnection):
                     _iam_id = headers.get('impersonate', {}).get('iam_id')
 
                 self._wml_client._iam_id = _iam_id
-                
-                if self._check_if_connection_asset_is_s3():
-                    # note: update flight parameters only if `connection_properties` was not set earlier
-                    #       (e.x. by wml/autoi)
-                    if not flight_parameters.get('connection_properties'):
-                        flight_parameters = self._update_flight_parameters_with_connection_details(flight_parameters)
+
                 try:
+                    if self._check_if_connection_asset_is_s3():
+                        # note: update flight parameters only if `connection_properties` was not set earlier
+                        #       (e.x. by wml/autoi)
+                        if not flight_parameters.get('connection_properties'):
+                            flight_parameters = self._update_flight_parameters_with_connection_details(flight_parameters)
+
                     data = self._download_data_from_flight_service(data_location=self,
                                                                    binary=binary,
                                                                    read_to_file=read_to_file,
                                                                    flight_parameters=flight_parameters,
                                                                    headers=headers,
                                                                    number_of_batch_rows=number_of_batch_rows)
-                except (ConnectionError, FlightError) as flight_connection_error:
-                    # note: try to download normal data asset directly from cams - to keep backward compatibility
-                    if self._wml_client and not self._check_if_connection_asset_is_s3():
+
+                except (ConnectionError, FlightError, ApiRequestFailure) as download_data_error:
+                    # note: try to download normal data asset either directly from cams or from mounted NFS
+                    #       to keep backward compatibility
+                    if self._wml_client and (self._is_data_asset_normal() or self._is_data_asset_nfs()):
                         import warnings
-                        warnings.warn(str(flight_connection_error), Warning)
+                        warnings.warn(str(download_data_error), Warning)
                         data = self._download_training_data_from_data_asset_storage()
                     else:
-                        raise flight_connection_error
+                        raise download_data_error
 
 
 
