@@ -591,14 +591,12 @@ class FlightConnection:
                 all of the mini batches needed are already stored in the memory.
         """
         self.callback.status_message("Starting reading training data in batches...")
-
         if self.enable_subsampling:
             for data in self.read():
                 yield data
             self.enable_subsampling = False
 
         sequences = []
-
         for n, endpoints in enumerate(self.get_endpoints()):
             self.max_flight_batch_number = len(endpoints)  # when flight does not want to open more endpoints
             threads = []
@@ -610,7 +608,6 @@ class FlightConnection:
                 logger.debug(f"IR: Starting batch reading thread: {i}, sequence: {n}...")
                 reading_thread.start()
 
-
         for n, batch in enumerate(self.create_logical_batch(timeout=60 * 60, _type='data')):
             logger.debug(f"IR: Logical batch number {n} received.")
             logger.debug(f"IR: Passing batch to upper layer.")
@@ -741,6 +738,9 @@ class FlightConnection:
                     return self.logical_batch_size_limit // self.row_size
 
             else:
+                if self.threads_exceptions:
+                    logger.debug(f"R: Partitions Thread Errors: {self.threads_exceptions}")
+                    raise DataStreamError(reason=str(self.threads_exceptions))
                 time.sleep(1)
 
     def regression_random_sampling(self, label_column: str) -> None:
