@@ -113,7 +113,7 @@ SEARCH_SCRIPT = u'{}/v2/asset_types/script/search'
 GIT_BASED_PROJECT_ASSET = u'{}/userfs/v2/assets/{}'
 GIT_BASED_PROJECT_ASSETS = u'{}/userfs/v2/assets'
 GIT_BASED_PROJECT_ASSET_TYPE = u'{}/userfs/v2/asset_types'
-GIT_BASED_PROJECT_ASSET_FILES = u'{}/userfs/v2/asset_files/'
+GIT_BASED_PROJECT_ASSET_FILES = u'{}/v2/asset_files/'
 GIT_BASED_PROJECT_ATTACHMENT = u'{}/userfs/v2/assets/{}/attachments/{}'
 GIT_BASED_PROJECT_ATTACHMENT_COMPLETE = u'{}/userfs/v2/assets/{}/attachments/{}/complete'
 GIT_BASED_PROJECT_ATTACHMENTS = u'{}/userfs/v2/assets/{}/attachments'
@@ -417,7 +417,7 @@ class HrefDefinitions:
         return (ASSET_FILES if not self._is_git_based_project() else GIT_BASED_PROJECT_ASSET_FILES)\
             .format(self._wml_credentials['url'])
 
-    def get_wsd_asset_search_href(self, asset_type):
+    def get_asset_search_href(self, asset_type):
         return (SEARCH_ASSETS if not self._is_git_based_project() else GIT_BASED_PROJECT_SEARCH_ASSETS)\
             .format(self._wml_credentials['url'], asset_type)
 
