@@ -108,8 +108,10 @@ if fl_path not in sys.path:
 
 
 class Party(WMLResource):
-    """
-    Party Wrapper for determining required version of FL Party to invoke.
+    """ 
+    The Party class embodies a Federated Learning party, with methods to run, cancel, and query local training.
+    Refer to the ``client.remote_training_system.create_party()`` API for more information about creating an
+    instance of the Party class. 
     """
 
     SUPPORTED_PLATFORMS_MAP = {
@@ -311,8 +313,8 @@ class Party(WMLResource):
 
     def monitor_logs(self, log_level="INFO"):
         """
-        This method should be called prior to the run() method to
-        enable the logs of the training job in the standard output
+        Enable logging of the training job to standard output.
+        This method should be called before calling the run() method.
 
         **Parameters**
 
@@ -334,12 +336,12 @@ class Party(WMLResource):
 
     def monitor_metrics(self, metrics_file="-"):
         """
-        Enable the metrics of the training job in the standard output
+        Enable output of training metrics.
 
         **Parameters**
 
         .. important::
-           #. **metrics_file**:  a filename specified by user for metrics output\n
+           #. **metrics_file**:  a filename specified by user to which the metrics should be written\n
               **type**: str\n
 
         **Output**
