@@ -36,9 +36,9 @@ class Script(WMLResource):
         self._ICP = client.ICP
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
-    def get_details(self, script_uid):
+    def get_details(self, script_uid=None):
         """
-            Get script asset details.
+            Get script asset details. If no script_uid is passed, details for all script assets will be returned.
 
             **Parameters**
 
@@ -57,34 +57,25 @@ class Script(WMLResource):
              >>> script_details = client.scripts.get_details(script_uid)
 
         """
-        Script._validate_type(script_uid, u'script_uid', STR_TYPE, True)
-
-        response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(script_uid), params=self._client._params(),
-                                headers=self._client._get_headers())
-
-        if response.status_code == 200:
-            response = self._get_required_element_from_response(self._handle_response(200, u'get asset details', response))
-
+        def get_required_elements(response):
             if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
                 return response
             else:
-
-                entity = response[u'entity']
-
-                try:
-                    del entity[u'script'][u'ml_version']
-                except KeyError:
-                    pass
-
                 final_response = {
                     "metadata": response[u'metadata'],
-                    "entity": entity
                 }
 
+                if 'entity' in response:
+                    final_response['entity'] = response[u'entity']
+
+                    try:
+                        del final_response['entity'][u'script'][u'ml_version']
+                    except KeyError:
+                        pass
+
                 return final_response
 
-        else:
-            return self._handle_response(200, u'get asset details', response)
+        return self._get_asset_based_resource(script_uid, 'script', get_required_elements)
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def store(self, meta_props, file_path):
@@ -159,7 +150,6 @@ class Script(WMLResource):
 
         ##Step1: Create a data asset
         name = script_meta['metadata'][u'name']
-        f = {'file': (name, open(file_path, 'rb'), 'application/octet-stream')}
 
         if script_meta['metadata'].get('description') is not None:
             desc = script_meta['metadata'][u'description']
@@ -213,12 +203,14 @@ class Script(WMLResource):
             sw_spec_details = self._client.software_specifications.get_details(script_meta[u'software_spec_uid'])
 
             if lang == 'R':
-                rscript_sw_spec_id = self._client.software_specifications.get_id_by_name('default_r3.6')
+                rscript_sw_spec_ids = [self._client.software_specifications.get_id_by_name(sw_name)
+                                       for sw_name in ('default_r3.6', 'runtime-22.1-r3.6')]
 
-                if rscript_sw_spec_id != script_meta[u'software_spec_uid']:
-                    raise WMLClientError("For R scripts, only base software spec 'default_r3.6' is supported. Specify "
+                if script_meta[u'software_spec_uid'] not in rscript_sw_spec_ids:
+                    raise WMLClientError("For R scripts, only base software specs 'default_r3.6', 'runtime-22.1-r3.6' "
+                                         "are supported. Specify "
                                          "the id you get via "
-                                         "self._client.software_specifications.get_id_by_name('default_r3.6')")
+                                         "self._client.software_specifications.get_id_by_name(sw_name)")
 
             if(sw_spec_details[u'entity'][u'software_specification'][u'type'] == 'base'):
                 if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
@@ -396,19 +388,17 @@ class Script(WMLResource):
 
 
                     #Step3: Put content to attachment
-                    if not self._ICP:
-
-                        files = open(file_path)
-
-                        put_response = requests.put(
-                            attachment_url,
-                            data=files.read()
-                        )
-                    else:
-                        put_response = requests.put(
-                            self._wml_credentials['url'] + attachment_url,
-                            files=f
-                        )
+                    with open(file_path, 'rb') as f:
+                        if not self._ICP:
+                            put_response = requests.put(
+                                attachment_url,
+                                data=f.read()
+                            )
+                        else:
+                            put_response = requests.put(
+                                self._wml_credentials['url'] + attachment_url,
+                                files={'file': (name, f, 'application/octet-stream')}
+                            )
                     if put_response.status_code == 201 or put_response.status_code == 200:
                         # Step4: Complete attachment
                         complete_response = requests.post(
