@@ -36,9 +36,9 @@ class Shiny(WMLResource):
         self._ICP = client.ICP
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
-    def get_details(self, shiny_uid):
+    def get_details(self, shiny_uid=None):
         """
-            Get shiny asset details.
+            Get shiny asset details. If no shiny_uid is passed, details for all shiny assets will be returned.
 
             **Parameters**
 
@@ -57,14 +57,7 @@ class Shiny(WMLResource):
              >>> shiny_details = client.shiny.get_details(shiny_uid)
 
         """
-        Shiny._validate_type(shiny_uid, u'shiny_uid', STR_TYPE, True)
-
-        response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(shiny_uid), params=self._client._params(),
-                                headers=self._client._get_headers())
-
-        if response.status_code == 200:
-            response = self._get_required_element_from_response(self._handle_response(200, u'get shiny asset details', response))
-
+        def get_required_elements(response):
             if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
                 return response
             else:
@@ -74,9 +67,8 @@ class Shiny(WMLResource):
                 }
 
                 return final_response
-            # return self._get_required_element_from_response(self._handle_response(200, u'get shiny asset details', response))
-        else:
-            return self._handle_response(200, u'get shiny asset details', response)
+
+        return self._get_asset_based_resource(shiny_uid, 'shiny_asset', get_required_elements)
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def store(self, meta_props, file_path):
@@ -136,7 +128,6 @@ class Shiny(WMLResource):
 
         ##Step1: Create a shiny asset
         name = shiny_meta[u'name']
-        f = {'file': (name, open(file_path, 'rb'), 'application/octet-stream')}
 
         if shiny_meta.get('description') is not None:
             desc = shiny_meta[u'description']
@@ -250,17 +241,18 @@ class Shiny(WMLResource):
 
 
                     #Step3: Put content to attachment
-                    if not self._ICP:
-                        put_response = requests.put(
-                            attachment_url,
-                            data=open(file_path, 'rb').read(),
-                            # files = f
-                        )
-                    else:
-                        put_response = requests.put(
-                            self._wml_credentials['url'] + attachment_url,
-                            files=f
-                        )
+                    with open(file_path, 'rb') as f:
+                        if not self._ICP:
+                            put_response = requests.put(
+                                attachment_url,
+                                data=f.read(),
+                                # files = f
+                            )
+                        else:
+                            put_response = requests.put(
+                                self._wml_credentials['url'] + attachment_url,
+                                files={'file': (name, f, 'application/octet-stream')}
+                            )
                     if put_response.status_code == 201 or put_response.status_code == 200:
                         # Step4: Complete attachment
                         complete_response = requests.post(
