@@ -33,7 +33,8 @@ __all__ = [
     'PositiveLabelClass',
     'VisualizationTypes',
     'SamplingTypes',
-    'ImputationStrategy'
+    'ImputationStrategy',
+    'ForecastingPipelineTypes'
 ]
 
 
@@ -151,6 +152,53 @@ class ForecastingAlgorithms(Enum):
     SVM = "SVM"
 
 
+class ForecastingPipelineTypes(Enum):
+    """Forecasting pipeline types that AutoAI could use for IBM Cloud Pak® for Data(CP4D)."""
+    RandomForestRegressor = 'RandomForestRegressor'
+    ExogenousRandomForestRegressor = 'ExogenousRandomForestRegressor'
+    SVM = 'SVM'
+    ExogenousSVM = 'ExogenousSVM'
+    LocalizedFlattenEnsembler = 'LocalizedFlattenEnsembler'
+    DifferenceFlattenEnsembler = 'DifferenceFlattenEnsembler'
+    FlattenEnsembler = 'FlattenEnsembler'
+    ExogenousLocalizedFlattenEnsembler = 'ExogenousLocalizedFlattenEnsembler'
+    ExogenousDifferenceFlattenEnsembler = 'ExogenousDifferenceFlattenEnsembler'
+    ExogenousFlattenEnsembler = 'ExogenousFlattenEnsembler'
+    MT2RForecaster = 'MT2RForecaster'
+    ExogenousMT2RForecaster = 'ExogenousMT2RForecaster'
+    HoltWinterAdditive = 'HoltWinterAdditive'
+    HoltWinterMultiplicative = 'HoltWinterMultiplicative'
+    Bats = 'Bats'
+    ARIMA = 'ARIMA'
+    ARIMAX = 'ARIMAX'
+    ARIMAX_RSAR = 'ARIMAX_RSAR'
+    ARIMAX_PALR = 'ARIMAX_PALR'
+    ARIMAX_RAR = 'ARIMAX_RAR'
+    ARIMAX_DMLR = 'ARIMAX_DMLR'
+
+    @staticmethod
+    def get_exogenous():
+        """
+        Get list of exogenous pipelines.
+
+        Returns
+        -------
+        List of exogenous pipelines.
+        """
+        return [pipeline for pipeline in ForecastingPipelineTypes if pipeline.value.startswith('Exogenous')]
+
+    @staticmethod
+    def get_non_exogenous():
+        """
+        Get list of non-exogenous pipelines.
+
+        Returns
+        -------
+        List of non-exogenous pipelines.
+        """
+        return [pipeline for pipeline in ForecastingPipelineTypes if not pipeline.value.startswith('Exogenous')]
+
+
 class PredictionType:
     """
         Supported types of learning.
