@@ -731,6 +731,8 @@ def prepare_interaction_props_for_cos(source_params: dict, file_name: str) -> di
             interaction_properties["sheet_name"] = str(source_params.get("excel_sheet"))
 
     elif '.csv' in file_name:
+        if source_params.get("quote_character"):
+            interaction_properties["quote_character"] = str(source_params.get("quote_character"))
         if encoding is not None:
             interaction_properties["encoding"] = encoding
 
